@@ -134,3 +134,5 @@ def main():
     except KeyboardInterrupt:
         logging.info("\n\n" + str(image_counter) + " Images Downloaded!!")
         logging.info(str(video_counter) + " Videos Downloaded!!")
+if __name__ == '__main__':
+    main()
